APLNativeConfiguration class abstract
Subclass APLNativeConfiguration to provide read only introspection of the
properties implemented in the native app's APLConfiguration subclass.
For any properties that you with to introspect in Dart, implement as follows depending on the type declared in Obj-C / Swift:
-- Boolean --
Dart: bool get propertyName => nativeBool('propertyName');
Swift: @BoolProperty(...) var propertyName: Bool
Obj-C: BOOL_PROPERTY(propertyName, ...);
-- String / Encrypted String --
Dart: String get propertyName => nativeString('propertyName');
Swift: @StringPropertyEdit(...) var propertyName: String
@StringPropertyList(...) var propertyName: String
@StringPropertyListEdit(...) var propertyName: String
@EncryptedStringPropertyListEdit(...) var propertyName: String
Obj-C: STRING_PROPERTY_EDIT(propertyName, ...);
STRING_PROPERTY_LIST(propertyName, ...);
STRING_PROPERTY_LIST_EDIT(propertyName, ...);
ENCRYPTED_STRING_PROPERTY_LIST_EDIT(propertyName, ...);
-- Integer --
Dart: int get propertyName => nativeInt('propertyName');
Swift: @IntPropertySlider(...) var propertyName: Int
@IntPropertyEdit(...) var propertyName: Int
@IntPropertyList(...) var propertyName: Int
@IntPropertyListEdit(...) var propertyName: Int
Obj-C: INT_PROPERTY_SLIDER(propertyName, ...);
INT_PROPERTY_EDIT(propertyName, ...);
INT_PROPERTY_LIST(propertyName, ...);
INT_PROPERTY_LIST_EDIT(propertyName ...);
-- Float / Double --
Dart: double get propertyName => nativeDouble('propertyName');
Swift: @FloatPropertySlider(...) var propertyName: Float
@FloatPropertyEdit(...) var propertyName: Float
@FloatPropertyList(...) var propertyName: Float
@FloatPropertyListEdit(...) var propertyName: Float
@DoublePropertySlider(...) var propertyName: Double
@DoublePropertyEdit(...) var propertyName: Double
@DoublePropertyList(...) var propertyName: Double
@DoublePropertyListEdit(...) var propertyName: Double
Obj-C: FLOAT_PROPERTY_SLIDER(propertyName, ...);
FLOAT_PROPERTY_EDIT(propertyName, ...);
FLOAT_PROPERTY_LIST(propertyName, ...);
FLOAT_PROPERTY_LIST_EDIT(propertyName, ...);
DOUBLE_PROPERTY_SLIDER(propertyName, ...);
DOUBLE_PROPERTY_EDIT(propertyName, ...);
DOUBLE_PROPERTY_LIST(propertyName, ...);
DOUBLE_PROPERTY_LIST_EDIT(propertyName, ...);
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
actionExecuted(
String action) → void -
Called when an
actionis executed. -
description(
) → String - Returns the textual representation of all properties.
-
modifications(
) → String - Returns the textual representation of all properties that have non default (overridden) values.
-
nativeBool(
String propertyName) → bool -
Introspect the native app's
APLConfigurationsubclass for theBOOL(Obj-C),Bool(Swift) with thepropertyNamespecified. -
nativeDouble(
String propertyName) → double -
Introspect the native app's
APLConfigurationsubclass for thefloat/double(Obj-C),Float/Double(Swift) with thepropertyNamespecified. -
nativeInt(
String propertyName) → int -
Introspect the native app's
APLConfigurationsubclass for theNSInteger(Obj-C),Int(Swift) with thepropertyNamespecified. -
nativeString(
String propertyName) → String -
Introspect the native app's
APLConfigurationsubclass for theNSString(Obj-C),String(Swift) with thepropertyNamespecified. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited